@@ -237,18 +237,20 @@ sub compare_and_rank {
 
     # 0/1
     push @dataframe, join ';', qq/T|$tar/,
-      ( split //, $tar_binary_hash->{$tar}{binary_digit_string} );    # Add Target
+      ( split //, $tar_binary_hash->{$tar}{binary_digit_string} );  # Add Target
 
     # Sort %score by value and load results
     my $count = 1;
-    $max_out++;                                                       # to be able to start w/ ONE
+    $max_out++;    # to be able to start w/ ONE
 
     # Start loop
     for my $key (
         sort {
-            $sort_by eq 'jaccard'                                    #
-              ? $score->{$b}{$sort_by} <=> $score->{$a}{$sort_by}    # 1 to 0 (similarity)
-              : $score->{$a}{$sort_by} <=> $score->{$b}{$sort_by}    # 0 to N (distance)
+            $sort_by eq 'jaccard'           #
+              ? $score->{$b}{$sort_by}
+              <=> $score->{$a}{$sort_by}    # 1 to 0 (similarity)
+              : $score->{$a}{$sort_by}
+              <=> $score->{$b}{$sort_by}    # 0 to N (distance)
         } keys %$score
       )
     {
@@ -270,10 +272,10 @@ sub compare_and_rank {
             }
           );
 
-        # *** IMPORTANT ***
-        # The LENGTH of the alignment is based on the #variables in the REF-COHORT
-        # Compute estimated av and dev for binary_string of L = length_align - n_00
-        # Corrected length_align L = length_align - n_00
+     # *** IMPORTANT ***
+     # The LENGTH of the alignment is based on the #variables in the REF-COHORT
+     # Compute estimated av and dev for binary_string of L = length_align - n_00
+     # Corrected length_align L = length_align - n_00
         my $length_align_corrected = $length_align - $n_00;
 
         #$estimated_average, $estimated_std_dev
@@ -473,10 +475,10 @@ qq/$char1 $format{ $char1 . $char2 } $char2 | (w:$val|d:$distance_pretty|cd:$cum
         push @out_csv,
 qq/$ref_key;$char1;$format{ $char1 . $char2 };$char2;$glob_hash->{$key};$distance;$sorted_key;$label/;
 
-        #REF(107:week_0_arm_1);indicator;TAR(125:week_0_arm_1);weight;hamming-distance;json-path
-        #0;;0;1;0;diseases.ageOfOnset.ageRange.end.iso8601duration.P16Y
-        #0;;0;1;0;diseases.ageOfOnset.ageRange.end.iso8601duration.P24Y
-        #1;-----;1;1;0;diseases.ageOfOnset.ageRange.end.iso8601duration.P39Y
+#REF(107:week_0_arm_1);indicator;TAR(125:week_0_arm_1);weight;hamming-distance;json-path
+#0;;0;1;0;diseases.ageOfOnset.ageRange.end.iso8601duration.P16Y
+#0;;0;1;0;diseases.ageOfOnset.ageRange.end.iso8601duration.P24Y
+#1;-----;1;1;0;diseases.ageOfOnset.ageRange.end.iso8601duration.P39Y
     }
     return $n_00, \$out_ascii, \@out_csv;
 }
@@ -611,8 +613,8 @@ sub set_excluded_phenotypicFeatures {
             # Remove the feature by setting it to undef
             $feature = undef;
 
-            # Due to properties being set to undef, it's possible for the coverage file to
-            # report phenotypicFeatures as 100% by all "excluded" = true
+  # Due to properties being set to undef, it's possible for the coverage file to
+  # report phenotypicFeatures as 100% by all "excluded" = true
         }
     }
 
@@ -623,7 +625,7 @@ sub remap_hash {
     my $arg    = shift;
     my $hash   = $arg->{hash};
     my $weight = $arg->{weight};
-    my $self   = $arg->{self};                                  # $self from $arg
+    my $self   = $arg->{self};                                 # $self from $arg
     my $nodes  = $self->{nodes};
     my $edges  = $self->{edges};
     my $format = $self->{format};
@@ -645,16 +647,16 @@ sub remap_hash {
     #print Dumper $hash;
     return {} unless %$hash;
 
-    # A bit more pruning plus folding
-    # NB: Hash::Fold keeps white spaces on keys
-    #
-    # Options for 1D-array folding:
-    # A) Array to Hash then Fold
-    # B) Fold then Regex <=== CHOSEN
-    #  - Avoids the need for deep cloning
-    #  - Works across any JSON data structure (without specific key requirements)
-    #  - BUT profiling shows it's ~5-10% slower than 'Array to Hash then Fold'
-    #  - Does not accommodate specific remappings like 'interpretations.diagnosis.genomicInterpretations'
+# A bit more pruning plus folding
+# NB: Hash::Fold keeps white spaces on keys
+#
+# Options for 1D-array folding:
+# A) Array to Hash then Fold
+# B) Fold then Regex <=== CHOSEN
+#  - Avoids the need for deep cloning
+#  - Works across any JSON data structure (without specific key requirements)
+#  - BUT profiling shows it's ~5-10% slower than 'Array to Hash then Fold'
+#  - Does not accommodate specific remappings like 'interpretations.diagnosis.genomicInterpretations'
     set_excluded_phenotypicFeatures( $hash, $switch, $format );
     $hash = fold($hash);
 
@@ -669,7 +671,7 @@ sub remap_hash {
     my $misc_regex_qr =
       qr/1900-01-01|NA0000|NCIT:C126101|P999Y|P9999Y|phenopacket_id/;
 
-    # Pre-compile a list of fixed scalar values to exclude into a hash for quick lookup
+# Pre-compile a list of fixed scalar values to exclude into a hash for quick lookup
     my %exclude_values =
       map { $_ => 1 }
       ( 'NA', 'NaN', 'Fake', 'None:No matching concept', 'Not Available' );
@@ -683,10 +685,10 @@ sub remap_hash {
         # Discard undefined
         next unless defined $hash->{$key};
 
-        # Discarding lines with 'low quality' keys (Time of regex profiled with :NYTProf: ms time)
-        # Some can be "rescued" by adding the ontology as ($1)
-        # NB1: We discard _labels too!!
-        # NB2: info|metaData are always discarded
+# Discarding lines with 'low quality' keys (Time of regex profiled with :NYTProf: ms time)
+# Some can be "rescued" by adding the ontology as ($1)
+# NB1: We discard _labels too!!
+# NB2: info|metaData are always discarded
         next
           if ( defined $exclude_variables_regex_qr
             && $key =~ $exclude_variables_regex_qr );
@@ -700,11 +702,12 @@ sub remap_hash {
         # Load values
         my $val = $hash->{$key};
 
-        # Discarding lines with unsupported val (Time profiled with :NYTProf: ms time)
+  # Discarding lines with unsupported val (Time profiled with :NYTProf: ms time)
         next
           if (
-            ( ref($val) eq 'HASH' && !keys %{$val} )    # Discard {} (e.g.,subject.vitalStatus: {})
-            || ( ref($val) eq 'ARRAY' && !@{$val} )     # Discard []
+            ( ref($val) eq 'HASH'
+                && !keys %{$val} )   # Discard {} (e.g.,subject.vitalStatus: {})
+            || ( ref($val) eq 'ARRAY' && !@{$val} )    # Discard []
             || exists $exclude_values{$val}
             || $val =~ $misc_regex_qr
           );
@@ -726,8 +729,8 @@ sub remap_hash {
         # Assign weights #
         ##################
 
-        # NB: mrueda (04-12-23) - it's ok if $weight == undef => NO AUTOVIVIFICATION!
-        # NB: We don't warn if user selection does not exist, just assign 1
+   # NB: mrueda (04-12-23) - it's ok if $weight == undef => NO AUTOVIVIFICATION!
+   # NB: We don't warn if user selection does not exist, just assign 1
 
         my $tmp_key_at_term_level = $tmp_key_at_variable_level;
 
@@ -751,11 +754,11 @@ sub remap_hash {
               # VARIABLE LEVEL
               # NB: exists stringifies the weights
               exists $weight->{$tmp_key_at_variable_level}
-              ? $weight->{$tmp_key_at_variable_level} + 0    # coercing to number
+              ? $weight->{$tmp_key_at_variable_level} + 0   # coercing to number
 
               # TERM LEVEL
               : exists $weight->{$tmp_key_at_term_level}
-              ? $weight->{$tmp_key_at_term_level} + 0        # coercing to number
+              ? $weight->{$tmp_key_at_term_level} + 0       # coercing to number
 
               # NO WEIGHT
               : 1;
@@ -806,20 +809,21 @@ sub add_hpo_ascendants {
         $copy_parent_id = $1;
         $copy_parent_id =~ tr/_/:/;
 
-        # *** IMPORTANT ***
-        # We cannot add any label to the ascendants, otherwise they will
-        # not be matched by an indv down the tree
-        # Myopia
-        # Mild Myopia
-        # We want that 'Mild Myopia' matches 'Myopia', thus we can not add a label from 'Mild Myopia'
-        # Use the labels only for debug
+# *** IMPORTANT ***
+# We cannot add any label to the ascendants, otherwise they will
+# not be matched by an indv down the tree
+# Myopia
+# Mild Myopia
+# We want that 'Mild Myopia' matches 'Myopia', thus we can not add a label from 'Mild Myopia'
+# Use the labels only for debug
         my $asc_key = DEVEL_MODE ? $key . '.HPO_asc_DEBUG_ONLY' : $key;
         $asc_key =~ s/HP:$ontology/$copy_parent_id/g;
         push @ascendants, $asc_key;
 
         # We finally add the label to %nomenclature
-        my $hpo_asc_str = $hpo_url . $copy_parent_id;    # 'http://purl.obolibrary.org/obo/HP_HP:0000539
-        $hpo_asc_str =~ s/HP://;                         # 0000539
+        my $hpo_asc_str = $hpo_url
+          . $copy_parent_id;    # 'http://purl.obolibrary.org/obo/HP_HP:0000539
+        $hpo_asc_str =~ s/HP://;    # 0000539
         $nomenclature{$asc_key} = $nodes->{$hpo_asc_str}{lbl};
     }
     return \@ascendants;
@@ -835,8 +839,8 @@ sub add_id2key {
     # OBJECTIVE #
     #############
 
-    # This subroutine is important as it replaces the index (numeric) for a given
-    # array element by a selected ontology. It's done for all subkeys on that element
+# This subroutine is important as it replaces the index (numeric) for a given
+# array element by a selected ontology. It's done for all subkeys on that element
 
     #"interventionsOrProcedures" : [
     #     {
@@ -885,7 +889,7 @@ sub add_id2key {
         # Normal behaviour for BFF/PXF
         if ( defined $3 ) {
 
-            # If id_correspondence is an array (e.g., medicalActions) we have to grep the right match
+# If id_correspondence is an array (e.g., medicalActions) we have to grep the right match
             my $correspondence;
             if ( ref $id_correspondence->{$1} eq ref [] ) {
 
@@ -893,16 +897,21 @@ sub add_id2key {
                 # <medicalActions> <0> <treatment.routeOfAdministration.id>
                 my $subkey = ( split /\./, $3 )[0];    # treatment
                 $correspondence =
-                  first { $_ =~ m/^$subkey/ } @{ $id_correspondence->{$1} };   # treatment.agent.id
+                  first { $_ =~ m/^$subkey/ }
+                  @{ $id_correspondence->{$1} };       # treatment.agent.id
             }
             else {
                 $correspondence = $id_correspondence->{$1};
             }
 
             # Now that we know which is the term we use to find key-val in $hash
-            $tmp_key = $1 . ':' . $2 . '.' . $correspondence;    # medicalActions.0.treatment.agent.id
-            $val     = $hash->{$tmp_key};                        # DrugCentral:257
-            $key     = join '.', $1, $val, $3;                   # medicalActions.DrugCentral:257.treatment.routeOfAdministration.id
+            $tmp_key =
+                $1 . ':'
+              . $2 . '.'
+              . $correspondence;    # medicalActions.0.treatment.agent.id
+            $val = $hash->{$tmp_key};    # DrugCentral:257
+            $key = join '.', $1, $val, $3
+              ; # medicalActions.DrugCentral:257.treatment.routeOfAdministration.id
         }
 
         # MXF or similar (...we haven't encountered other regex yet)
@@ -978,20 +987,20 @@ sub create_binary_digit_string {
 sub parse_hpo_json {
     my $data = shift;
 
-    # The <hp.json> file is a structured representation of the Human Phenotype Ontology (HPO) in JSON format.
-    # The HPO is structured into a directed acyclic graph (DAG)
-    # Here's a brief overview of the structure of the hpo.json file:
-    # - graphs: This key contains an array of ontology graphs. In the case of HPO, there is only one graph. The graph has two main keys:
-    # - nodes: An array of objects, each representing an HPO term. Each term object has the following keys:
-    # - id: The identifier of the term (e.g., "HP:0000118").
-    # - lbl: The label (name) of the term (e.g., "Phenotypic abnormality").
-    # - meta: Metadata associated with the term, including definition, synonyms, and other information.
-    # - type: The type of the term, usually "CLASS".
-    # - edges: An array of objects, each representing a relationship between two HPO terms. Each edge object has the following keys:
-    # - sub: The subject (child) term ID (e.g., "HP:0000924").
-    # - obj: The object (parent) term ID (e.g., "HP:0000118").
-    # - pred: The predicate that describes the relationship between the subject and object terms, typically "is_a" in HPO.
-    # - meta: This key contains metadata about the HPO ontology as a whole, such as version information, description, and other details.
+# The <hp.json> file is a structured representation of the Human Phenotype Ontology (HPO) in JSON format.
+# The HPO is structured into a directed acyclic graph (DAG)
+# Here's a brief overview of the structure of the hpo.json file:
+# - graphs: This key contains an array of ontology graphs. In the case of HPO, there is only one graph. The graph has two main keys:
+# - nodes: An array of objects, each representing an HPO term. Each term object has the following keys:
+# - id: The identifier of the term (e.g., "HP:0000118").
+# - lbl: The label (name) of the term (e.g., "Phenotypic abnormality").
+# - meta: Metadata associated with the term, including definition, synonyms, and other information.
+# - type: The type of the term, usually "CLASS".
+# - edges: An array of objects, each representing a relationship between two HPO terms. Each edge object has the following keys:
+# - sub: The subject (child) term ID (e.g., "HP:0000924").
+# - obj: The object (parent) term ID (e.g., "HP:0000118").
+# - pred: The predicate that describes the relationship between the subject and object terms, typically "is_a" in HPO.
+# - meta: This key contains metadata about the HPO ontology as a whole, such as version information, description, and other details.
 
     my $graph = $data->{graphs}->[0];
     my %nodes = map { $_->{id} => $_ } @{ $graph->{nodes} };
@@ -1039,7 +1048,7 @@ sub binary_to_base64 {
     # Convert binary string (e.g. "0010...") to raw bytes
     my $raw_data = pack( "B*", $binary_string );
 
-    # Compress the raw data (note: compressing very short data may not save space)
+  # Compress the raw data (note: compressing very short data may not save space)
     my $compressed = compress($raw_data);
 
     # Base64 encode the compressed data, without any newline breaks
